// Load data from CSV file
d3.csv('https://gist.githubusercontent.com/anvesh2129/fd41c8b9e4ac2be354714cbdef9317f0/raw/8f901bab0a5ab008c71e1885933e50f3aee55e30/bikes_ind.csv')
  .then((data) => {
    // Convert top speed and max torque values to numeric type
    data.forEach((d) => {
      d.topSpeed = +d['top speed'];
      d.torque = +d['max torque'];
    });

    // Define margins for the chart
    const margin = {
      top: 20,
      right: 50,
      bottom: 99,
      left: 60,
    };

    // Define the width and height of the chart area
    const width = 600 - margin.left - margin.right;
    const height = 300 - margin.top - margin.bottom;

    // Create x and y scales for the chart
    const x = d3.scaleLinear()
      .domain(d3.extent(data, (d) => d.torque))
      .range([0, width]);

    const y = d3.scaleLinear()
      .domain(d3.extent(data, (d) => d.topSpeed))
      .range([height, 0]);

    // Create a color scale based on max torque values
    const color = d3.scaleLinear()
      .domain(d3.extent(data, (d) => d.torque))
      .range(['blue', 'red']);

    // Create an SVG element for the chart
    const svg = d3.select('#chart')
      .append('svg')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr('transform', `translate(${margin.left},${margin.top})`);

svg
  .append('g')
  .attr('transform', `translate(0, ${height})`) // move x-axis to the bottom of the chart
  .call(d3.axisBottom(x)) // create and append x-axis to svg
  .append('text')
  .attr('fill', '#000')
  .attr('x', width / 2)
  .attr('y', 50)
  .attr('text-anchor', 'middle')
  .style('font-weight', 'bold') // make text bold
  .style('fill', 'gray') // change color to red
  .text('Max Torque (Nm)'); // add label to x-axis

svg
  .append('g')
  .call(d3.axisLeft(y)) // create and append y-axis to svg
  .append('text')
  .attr('fill', '#000')
  .attr('x', -height / 2)
  .attr('y', -50)
  .attr('transform', 'rotate(-90)')
  .attr('text-anchor', 'middle')
  .style('font-weight', 'bold') // make text bold
  .style('fill', 'gray') // change color to red
  .text('Top Speed (km/h)'); // add label to y-axis

svg
  .selectAll('.dot')
  .data(data)
  .enter()
  .append('circle')
  .attr('class', 'dot') // add class name for css styling
  .attr('cx', (d) => x(d.torque)) // set x coordinate
  .attr('cy', (d) => y(d.topSpeed)) // set y coordinate
  .attr('r', 4) // set radius of circles
  .style('fill', (d) => color(d.torque)); // set fill color of circles based on torque value

// create a selection of all elements with class '.legend'
// bind the color scale's ticks (6 values in this case) as the data for this selection
// enter the selection to append a new group element for each tick value
// set the class and position of each group element
const legend = svg
  .selectAll('.legend')
  .data(color.ticks(6))
  .enter()
  .append('g')
  .attr('class', 'legend')
  .attr('transform', 'rotate(-90)')
  .attr(
    'transform',
    (d, i) =>
      `translate(${i * 90},${
        height + margin.top + 65
      })`
  );

// append a circle to each legend group
// set its position and fill color using the color scale
legend
  .append('circle')
  .attr('cx', 0)
  .attr('cy', 0)
  .attr('r', 5)
  .style('fill', color);

// append text to each legend group
// set the text value to the tick value and its position
// set the font size of the text
legend
  .append('text')
  .attr('x', 8)
  .attr('y', 5)
  .attr('dy', '.35em')
  .text((d) => d)
  .style('font-size', '12px');

// append text to each legend group
// set the text value to 'Torque (Nm)' and its position
// set the font size of the text
legend
  .append('text')
  .attr('x', 0)
  .attr('y', -10)
  .text('Torque (Nm)')
  .style('font-size', '12px');

});
